postalCode

# XMLRésuméLibrary: User Guide

possible | Element Reference | prefecture

## Name

postalCode — A postal code

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `postalCode` element contains an alphanumeric string used by postal services to route mail to its destination.

For postal codes in the United States, use `zip`.

### Parents

`postalCode` may be contained in these elements: `address`

## See Also

`zip`.

## Examples

A Brazilian postal code:

    <postalCode>85070-200</postalCode>

A Canadian postal code:

    <postalCode>V2B 5S8</postalCode>

possible | Element Reference | prefecture